@@ -1,20 +1,19 @@
 /*
- *  Copyright © 1998, 2003 Jonathan Blandford <jrb@alum.mit.edu>
- *  Copyright © 2007 Christian Persch
+ * Copyright © 1998, 2003 Jonathan Blandford <jrb@alum.mit.edu>
+ * Copyright © 2007 Christian Persch
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope game it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -253,7 +252,11 @@ clear_slots (AisleriotGame *game,
 #endif /* HAVE_CLUTTER */
     g_byte_array_free (slot->cards, TRUE);
 
+#if GLIB_CHECK_VERSION (2, 10, 0)
     g_slice_free (Slot, slot);
+#else
+    g_free (slot);
+#endif
   }
 
   g_ptr_array_set_size (game->slots, 0);
@@ -293,7 +296,7 @@ typedef struct {
   gboolean exception;
 } CallData;
 
-#define CALL_DATA_INIT  { 0, 0, 0, 0, 0, 0, 0 };
+#define CALL_DATA_INIT  { 0, 0, 0, 0, 0, 0, 0 }
 
 static char *
 cscmi_exception_get_backtrace (SCM tag, SCM throw_args)
@@ -493,23 +496,21 @@ c2scm_card (Card card)
                                        SCM_EOL)));
 }
 
-static Card
-scm2c_card (SCM card_data)
+static void
+scm2c_card (SCM card_data,
+            Card *card)
 {
-  Card card;
   guint rank, suit, face_down;
 
-  card.value = 0;
+  card->value = 0;
 
   rank = scm_to_int (SCM_CAR (card_data));
   suit = scm_to_int (SCM_CADR (card_data));
   face_down = !(SCM_NFALSEP (SCM_CADDR (card_data)));
 
-  card.attr.rank = rank;
-  card.attr.suit = suit;
-  card.attr.face_down = face_down;
-
-  return card;
+  card->attr.rank = rank;
+  card->attr.suit = suit;
+  card->attr.face_down = face_down;
 }
 
 static SCM
@@ -544,7 +545,10 @@ cscmi_slot_set_cards (Slot *slot,
     i = n_cards;
 
     for (list_el = cards; list_el != SCM_EOL; list_el = SCM_CDR (list_el)) {
-      data[--i] = CARD_UINT (scm2c_card (SCM_CAR (list_el)));
+      Card card;
+
+      scm2c_card (SCM_CAR (list_el), &card);
+      data[--i] = CARD_UINT (card);
     }
   }
 
@@ -596,7 +600,12 @@ cscmi_add_slot (SCM slot_data)
 #undef CHECK_EXPANSION
 
   /* create and initialize slot */
+#if GLIB_CHECK_VERSION (2, 10, 0)
   slot = g_slice_new0 (Slot);
+#else
+  slot = g_new0 (Slot, 1);
+#endif
+
   g_ptr_array_add (game->slots, slot);
 
   slot->id = scm_to_int (SCM_CAR (slot_data));
@@ -1217,6 +1226,9 @@ aisleriot_game_get_property (GObject *object,
     case PROP_SCORE:
       g_value_set_uint (value, game->score);
       break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
   }
 }
 
@@ -2039,7 +2051,11 @@ aisleriot_game_option_free (AisleriotGameOption *option)
   g_return_if_fail (option != NULL);
 
   g_free (option->display_name);
+#if GLIB_CHECK_VERSION (2, 10, 0)
   g_slice_free (AisleriotGameOption, option);
+#else
+  g_free (option);
+#endif
 }
 
 /**
@@ -2096,7 +2112,12 @@ aisleriot_game_get_options (AisleriotGame *game)
 
       entrystate = SCM_NFALSEP (scm_list_ref (entry, scm_from_uint (1)));
 
+#if GLIB_CHECK_VERSION (2, 10, 0)
       option = g_slice_new (AisleriotGameOption);
+#else
+      option = g_new (AisleriotGameOption, 1);
+#endif
+
       option->display_name = g_strdup (entrynamestr);
       option->type = type;
       option->value = bit;
@@ -2356,9 +2377,9 @@ aisleriot_game_get_card_offset (Slot *slot,
   }
 
   if (card_num >= n_cards - exposed) {
-    gint index = card_num + exposed - n_cards;
-    *xoff = slot->pixeldx * index;
-    *yoff = slot->pixeldy * index;
+    gint idx = card_num + exposed - n_cards;
+    *xoff = slot->pixeldx * idx;
+    *yoff = slot->pixeldy * idx;
   } else {
     *xoff = 0;
     *yoff = 0;
