@@ -1,19 +1,18 @@
 /*
- *  Copyright © 2008 Neil Roberts
+ * Copyright © 2008 Neil Roberts
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -22,6 +21,7 @@
 #include <gtk/gtk.h>
 #include <cogl/cogl.h>
 #include <string.h>
+#include <math.h>
 
 #include "slot-renderer.h"
 #include "card.h"
@@ -45,7 +45,6 @@ static void aisleriot_slot_renderer_set_cache (AisleriotSlotRenderer *srend,
 
 static void completed_cb (AisleriotSlotRenderer *srend);
 
-static const ClutterColor white = { 0xff, 0xff, 0xff, 0xff };
 static const ClutterColor default_highlight_color = { 0, 0, 0xaa, 0xff };
 
 G_DEFINE_TYPE (AisleriotSlotRenderer, aisleriot_slot_renderer,
@@ -63,6 +62,8 @@ struct _AisleriotSlotRendererPrivate
 
   Slot *slot;
 
+  CoglHandle material;
+
   ClutterColor highlight_color;
   gboolean show_highlight;
   gint highlight_start;
@@ -72,6 +73,7 @@ struct _AisleriotSlotRendererPrivate
   ClutterTimeline *timeline;
   guint completed_handler;
   GArray *animations;
+  guint n_unexposed_animated_cards;
 
   ClutterContainer *animation_layer;
 };
@@ -187,7 +189,7 @@ aisleriot_slot_renderer_init (AisleriotSlotRenderer *self)
   priv->highlight_color = default_highlight_color;
 
   priv->animations = g_array_new (FALSE, FALSE, sizeof (AnimationData));
-  priv->timeline = clutter_timeline_new_for_duration (500);
+  priv->timeline = clutter_timeline_new (500);
   g_signal_connect_swapped (priv->timeline, "completed",
                             G_CALLBACK (completed_cb), self);
 }
@@ -201,13 +203,18 @@ aisleriot_slot_renderer_dispose (GObject *object)
   aisleriot_slot_renderer_set_cache (self, NULL);
 
   /* Get rid of any running animations */
-  aisleriot_slot_renderer_set_animations (self, 0, NULL);
+  aisleriot_slot_renderer_set_animations (self, 0, NULL, 0);
 
   if (priv->timeline) {
     g_object_unref (priv->timeline);
     priv->timeline = NULL;
   }
 
+  if (priv->material != COGL_INVALID_HANDLE) {
+    cogl_handle_unref (priv->material);
+    priv->material = COGL_INVALID_HANDLE;
+  }
+
   aisleriot_slot_renderer_set_animation_layer (self, NULL);
 
   G_OBJECT_CLASS (aisleriot_slot_renderer_parent_class)->dispose (object);
@@ -328,6 +335,49 @@ aisleriot_slot_renderer_get_property (GObject *object,
   }
 }
 
+static void
+aisleriot_slot_renderer_set_material_for_card (AisleriotSlotRenderer *srend,
+                                               CoglHandle tex,
+                                               gboolean show_highlight)
+{
+  AisleriotSlotRendererPrivate *priv = srend->priv;
+  guint8 opacity = clutter_actor_get_paint_opacity (CLUTTER_ACTOR (srend));
+
+  if (priv->material == COGL_INVALID_HANDLE)
+    priv->material = cogl_material_new ();
+
+  if (show_highlight)
+    {
+      CoglColor color;
+
+      /* The previous code for drawing the highlight rendered the
+         normal card texture and then rendered the card again
+         multiplied by the highlight color but with 50%
+         transparency. The blend function is alpha*src+(1-alpha*dst)
+         where src is effectively the tex times the highlight color
+         and the dst is the original tex. Therefore the final color is
+         0.5*tex+0.5*tex*highlight which is the same as
+         (0.5+highlight/2)*tex. We can precompute that value to avoid
+         having to draw the card twice */
+      cogl_color_set_from_4ub (&color,
+                               MIN (priv->highlight_color.red
+                                    / 2 + 128, 0xff),
+                               MIN (priv->highlight_color.green
+                                    / 2 + 128, 0xff),
+                               MIN (priv->highlight_color.blue
+                                    / 2 + 128, 0xff),
+                               opacity);
+      cogl_color_premultiply (&color);
+      cogl_material_set_color (priv->material, &color);
+    }
+  else
+    cogl_material_set_color4ub (priv->material,
+                                opacity, opacity, opacity, opacity);
+
+  cogl_material_set_layer (priv->material, 0, tex);
+  cogl_set_source (priv->material);
+}
+
 static void
 aisleriot_slot_renderer_paint_card (AisleriotSlotRenderer *srend,
                                     guint card_num)
@@ -349,26 +399,11 @@ aisleriot_slot_renderer_paint_card (AisleriotSlotRenderer *srend,
                                   FALSE,
                                   &cardx, &cardy);
 
-  cogl_color (&white);
-  cogl_texture_rectangle (cogl_tex,
-                          CLUTTER_INT_TO_FIXED (cardx),
-                          CLUTTER_INT_TO_FIXED (cardy),
-                          CLUTTER_INT_TO_FIXED (cardx + tex_width),
-                          CLUTTER_INT_TO_FIXED (cardy + tex_height),
-                          0, 0, CFX_ONE, CFX_ONE);
+  aisleriot_slot_renderer_set_material_for_card
+    (srend, cogl_tex,
+     priv->show_highlight && card_num >= priv->highlight_start);
 
-  if (priv->show_highlight && (card_num >= priv->highlight_start)) {
-    ClutterColor color = priv->highlight_color;
-
-    color.alpha = 0x80;
-    cogl_color (&color);
-    cogl_texture_rectangle (cogl_tex,
-                            CLUTTER_INT_TO_FIXED (cardx),
-                            CLUTTER_INT_TO_FIXED (cardy),
-                            CLUTTER_INT_TO_FIXED (cardx + tex_width),
-                            CLUTTER_INT_TO_FIXED (cardy + tex_height),
-                            0, 0, CFX_ONE, CFX_ONE);
-  }
+  cogl_rectangle (cardx, cardy, cardx + tex_width, cardy + tex_height);
 }
 
 static void
@@ -376,7 +411,7 @@ aisleriot_slot_renderer_paint (ClutterActor *actor)
 {
   AisleriotSlotRenderer *srend = (AisleriotSlotRenderer *) actor;
   AisleriotSlotRendererPrivate *priv = srend->priv;
-  guint n_cards;
+  guint n_cards, n_animated_cards;
   guint8 *cards;
   guint i;
 
@@ -385,46 +420,32 @@ aisleriot_slot_renderer_paint (ClutterActor *actor)
 
   cards = priv->slot->cards->data;
   n_cards = priv->slot->cards->len;
+  n_animated_cards = priv->animations->len + priv->n_unexposed_animated_cards;
 
   g_assert (n_cards >= priv->slot->exposed);
-  g_assert (n_cards >= priv->animations->len);
+  g_assert (priv->n_unexposed_animated_cards == 0 || priv->animations->len > 0);
+  g_assert (n_cards >= n_animated_cards);
 
-  if (priv->slot->cards->len <= priv->animations->len) {
+  if (n_cards <= n_animated_cards) {
     CoglHandle cogl_tex;
     guint tex_width, tex_height;
 
     cogl_tex = games_card_textures_cache_get_slot_texture (priv->cache);
     if (G_UNLIKELY (cogl_tex == COGL_INVALID_HANDLE))
-      goto paint_cards;
+      return;
 
     tex_width = cogl_texture_get_width (cogl_tex);
     tex_height = cogl_texture_get_height (cogl_tex);
 
-    cogl_color (&white);
-    cogl_texture_rectangle (cogl_tex,
-                            0, 0,
-                            CLUTTER_INT_TO_FIXED (tex_width),
-                            CLUTTER_INT_TO_FIXED (tex_height),
-                            0, 0, CFX_ONE, CFX_ONE);
-
-    if (priv->show_highlight) {
-      cogl_color (&priv->highlight_color);
-      cogl_texture_rectangle (cogl_tex,
-                              0, 0,
-                              CLUTTER_INT_TO_FIXED (tex_width),
-                              CLUTTER_INT_TO_FIXED (tex_height),
-                              0, 0, CFX_ONE, CFX_ONE);
-    }
-  }
-
-paint_cards:
-
-  if (n_cards > priv->animations->len) {
+    aisleriot_slot_renderer_set_material_for_card (srend, cogl_tex,
+                                                   priv->show_highlight);
+    cogl_rectangle (0, 0, tex_width, tex_height);
+  } else {
     guint first_card, last_card;
 
-    first_card = MIN (n_cards - priv->animations->len - 1,
+    first_card = MIN (n_cards - n_animated_cards - 1,
                       n_cards - priv->slot->exposed);
-    last_card = n_cards - priv->animations->len;
+    last_card = n_cards - n_animated_cards;
 
     for (i = first_card; i < last_card; i++)
       if (i != priv->revealed_card)
@@ -538,10 +559,20 @@ aisleriot_slot_renderer_set_animation_layer (AisleriotSlotRenderer *srend,
   g_object_notify (G_OBJECT (srend), "animation-layer");
 }
 
+static gdouble
+aisleriot_slot_sine_animation_mode (ClutterAlpha *alpha,
+                                    gpointer data)
+{
+  ClutterTimeline *tl = clutter_alpha_get_timeline (alpha);
+
+  return sin (clutter_timeline_get_progress (tl) * G_PI);
+}
+
 void
 aisleriot_slot_renderer_set_animations (AisleriotSlotRenderer *srend,
                                         guint n_anims,
-                                        const AisleriotAnimStart *anims)
+                                        const AisleriotAnimStart *anims,
+                                        guint n_unexposed_animated_cards)
 {
   AisleriotSlotRendererPrivate *priv;
   guint i;
@@ -579,11 +610,17 @@ aisleriot_slot_renderer_set_animations (AisleriotSlotRenderer *srend,
     ClutterAlpha *alpha;
     ClutterKnot knots[2];
     Card card = CARD (priv->slot->cards->data[card_num]);
-    guint card_width = 0, card_height = 0;
+    guint card_width, card_height;
 
     memset (&anim_data, 0, sizeof (anim_data));
 
-    anim_data.card_tex = aisleriot_card_new (priv->cache, card, &priv->highlight_color);
+    anim_data.card_tex = aisleriot_card_new (priv->cache,
+                                             anims[i].old_card,
+                                             card);
+
+    card_width = clutter_actor_get_width (anim_data.card_tex);
+    card_height = clutter_actor_get_height (anim_data.card_tex);
+
     g_object_ref_sink (anim_data.card_tex);
     if (priv->animation_layer)
       clutter_container_add (priv->animation_layer,
@@ -600,24 +637,16 @@ aisleriot_slot_renderer_set_animations (AisleriotSlotRenderer *srend,
     knots[1].x += priv->slot->rect.x;
     knots[1].y += priv->slot->rect.y;
 
-    alpha = clutter_alpha_new_full (priv->timeline, CLUTTER_ALPHA_RAMP_INC,
-                                    NULL, NULL);
+    alpha = clutter_alpha_new_full (priv->timeline, CLUTTER_LINEAR);
 
-    anim_data.move = clutter_behaviour_path_new (alpha, knots,
-                                                 G_N_ELEMENTS (knots));
+    anim_data.move
+      = clutter_behaviour_path_new_with_knots (alpha, knots,
+                                               G_N_ELEMENTS (knots));
     clutter_behaviour_apply (anim_data.move, anim_data.card_tex);
 
-    if (anims[i].face_down != card.attr.face_down) {
-      CoglHandle cogl_tex;
+    if (anims[i].old_card.value != card.value) {
       int center_x, center_y;
 
-      cogl_tex = games_card_textures_cache_get_card_texture (priv->cache, card);
-      if (G_UNLIKELY (cogl_tex == COGL_INVALID_HANDLE))
-        continue; // FIXMEchpe this doesn't look right...
-
-      card_width = cogl_texture_get_width (cogl_tex);
-      card_height = cogl_texture_get_height (cogl_tex);
-
       center_x = card_width / 2;
       center_y = card_height / 2;
 
@@ -637,8 +666,9 @@ aisleriot_slot_renderer_set_animations (AisleriotSlotRenderer *srend,
     }
 
     if (anims[i].raise) {
-      alpha = clutter_alpha_new_full (priv->timeline, CLUTTER_ALPHA_SINE,
-                                      NULL, NULL);
+      alpha = clutter_alpha_new_with_func (priv->timeline,
+                                           aisleriot_slot_sine_animation_mode,
+                                           NULL, NULL);
 
       anim_data.depth = clutter_behaviour_depth_new (alpha,
                                                      0, card_height);
@@ -655,6 +685,8 @@ aisleriot_slot_renderer_set_animations (AisleriotSlotRenderer *srend,
     clutter_timeline_start (priv->timeline);
   }
 
+  priv->n_unexposed_animated_cards = n_unexposed_animated_cards;
+
   clutter_actor_queue_redraw (CLUTTER_ACTOR (srend));
 }
 
@@ -662,7 +694,7 @@ static void
 completed_cb (AisleriotSlotRenderer *srend)
 {
   /* Get rid of all animation actors */
-  aisleriot_slot_renderer_set_animations (srend, 0, NULL);
+  aisleriot_slot_renderer_set_animations (srend, 0, NULL, 0);
 
   /* Redraw so that the animated actors will be drawn as part of the
      renderer instead */
