@@ -1,20 +1,19 @@
 /*
- *  Copyright © 2003 Callum McKenzie <callum@physics.otago.ac.nz>
- *  Copyright © 2007 Christian Persch
+ * Copyright © 2003 Callum McKenzie <callum@physics.otago.ac.nz>
+ * Copyright © 2007 Christian Persch
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope stats_dialog it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -25,6 +24,10 @@
 
 #include <libgames-support/games-stock.h>
 
+#ifndef HAVE_HILDON
+#include <libgames-support/games-atk-utils.h>
+#endif
+
 #include "conf.h"
 #include "util.h"
 
@@ -74,8 +77,8 @@ pack_in_frame (GtkWidget *box,
   gtk_widget_show_all (frame);
 
 #ifndef HAVE_HILDON
-  aisleriot_util_add_atk_relation (label, frame, ATK_RELATION_LABEL_FOR);
-  aisleriot_util_add_atk_relation (frame, label, ATK_RELATION_LABELLED_BY);
+  games_atk_util_add_atk_relation (label, frame, ATK_RELATION_LABEL_FOR);
+  games_atk_util_add_atk_relation (frame, label, ATK_RELATION_LABELLED_BY);
 #endif /* !HAVE_HILDON */
 }
 
@@ -99,8 +102,8 @@ add_row (GtkTable *table,
                              1, 2, row, row + 1);
 
 #ifndef HAVE_HILDON
-  aisleriot_util_add_atk_relation (label, data_label, ATK_RELATION_LABEL_FOR);
-  aisleriot_util_add_atk_relation (data_label, label, ATK_RELATION_LABELLED_BY);
+  games_atk_util_add_atk_relation (label, data_label, ATK_RELATION_LABEL_FOR);
+  games_atk_util_add_atk_relation (data_label, label, ATK_RELATION_LABELLED_BY);
 #endif /* !HAVE_HILDON */
 
   return GTK_LABEL (data_label);
@@ -143,17 +146,28 @@ aisleriot_stats_dialog_init (AisleriotStatsDialog *stats_dialog)
   gtk_table_set_row_spacings (table, 6);
   gtk_table_set_col_spacings (table, 12);
 
+  /* Translators: this is the total number of won games */
   priv->wins_label = add_row (table, 0, _("Wins:"));
+  /* Translators: this is the number of games played */
   priv->total_label = add_row (table, 1, _("Total:"));
+  /* Translators: this is the percentage of games won out of all games played */
   priv->percentage_label = add_row (table, 2, _("Percentage:"));
+  /* Translators: this is the section title of a section which contains the n
+   * number of games played, number of games won, and the ratio of these 2 numbers.
+   */
   pack_in_frame (hbox, GTK_WIDGET (table), _("Wins"));
 
   table = GTK_TABLE (gtk_table_new (2, 2, FALSE));
   gtk_table_set_row_spacings (table, 6);
   gtk_table_set_col_spacings (table, 12);
 
+  /* Translators: this is the best time of all wins */
   priv->best_label = add_row (table, 0, _("Best:"));
+  /* Translators: this is the worst time of all wins */
   priv->worst_label = add_row (table, 1, _("Worst:"));
+  /* Translators: this is the section title of a section containing the
+   * best and worst time taken to win a game.
+   */
   pack_in_frame (hbox, GTK_WIDGET (table), _("Time"));
 
   gtk_dialog_add_buttons (dialog,
