@@ -205,7 +205,7 @@ setupdialog_destroy (GtkWidget * widget, gint mode)
 static gint
 set_as_int (GtkWidget * widget, gpointer * data)
 {
-  *((int *) data) = GTK_TOGGLE_BUTTON (widget)->active;
+  *((int *) data) = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 
   return FALSE;
 }
@@ -268,7 +268,7 @@ setup_game (GtkAction * action, gpointer data)
 					     GTK_DIALOG_DESTROY_WITH_PARENT,
 					     GTK_STOCK_CLOSE,
 					     GTK_RESPONSE_CLOSE, NULL);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (setupdialog)->vbox), 2);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (setupdialog))), 2);
   gtk_window_set_resizable (GTK_WINDOW (setupdialog), FALSE);
   gtk_dialog_set_has_separator (GTK_DIALOG (setupdialog), FALSE);
   g_signal_connect (G_OBJECT (setupdialog), "delete_event",
@@ -282,8 +282,8 @@ setup_game (GtkAction * action, gpointer data)
   gtk_table_set_row_spacings (GTK_TABLE (table), 18);
   gtk_table_set_col_spacings (GTK_TABLE (table), 18);
 
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (setupdialog)->vbox), table,
-		      FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (setupdialog))), 
+                      table, FALSE, FALSE, 0);
 
   frame = games_frame_new (_("Human Players"));
   gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1, GTK_FILL, GTK_FILL,
@@ -345,9 +345,9 @@ setup_game (GtkAction * action, gpointer data)
   label = gtk_label_new_with_mnemonic (_("_Difficulty:"));
   gtk_box_pack_start(GTK_BOX(box2), label, FALSE, FALSE, 0);
   combo = gtk_combo_box_new_text();
-  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Easy"));
-  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Medium"));
-  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Hard"));
+  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), C_("difficulty", "Easy"));
+  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), C_("difficulty", "Medium"));
+  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), C_("difficulty", "Hard"));
   skill_level = 0;
   while (NUM_TRIALS > skill_level_table[skill_level].trials &&
          skill_level < (SKILL_LEVEL_TABLE_SIZE - 1)) skill_level++;
@@ -362,8 +362,8 @@ setup_game (GtkAction * action, gpointer data)
   gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 2, 3, GTK_FILL,
                     GTK_FILL | GTK_EXPAND, 0, 0);
   combo = gtk_combo_box_new_text();
-  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Regular"));
-  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Colors"));
+  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), C_("game type", "Regular"));
+  gtk_combo_box_append_text(GTK_COMBO_BOX(combo), C_("game type", "Colors"));
   gtk_combo_box_set_active(GTK_COMBO_BOX(combo), game_type);
   NewGameType = game_type;
   g_signal_connect (G_OBJECT (combo), "changed", G_CALLBACK (SetGameType),
