@@ -28,7 +28,6 @@
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "games-files.h"
 #include "games-runtime.h"
 
 #include "games-stock.h"
@@ -90,7 +89,7 @@ menu_item_select_cb (GtkWidget * widget, GtkStatusbar * statusbar)
 
   context_id = gtk_statusbar_get_context_id (statusbar, "games-tooltip");
 
-#if GTK_CHECK_VERSION (2, 8, 0)
+#if GTK_CHECK_VERSION (2, 10, 0)
   action = gtk_widget_get_action (widget);
 #else
   action = g_object_get_data (G_OBJECT (widget), "gtk-action");
@@ -271,7 +270,10 @@ games_stock_init (void)
     { GAMES_STOCK_NEW_GAME,         GTK_STOCK_NEW },
     { GAMES_STOCK_RESET,            GTK_STOCK_CLEAR },
     { GAMES_STOCK_RESTART_GAME,     GTK_STOCK_REFRESH },
+#if GTK_CHECK_VERSION (2, 8, 0)
+    /* This is used on hildon too, but only exists since 2.8 */
     { GAMES_STOCK_FULLSCREEN,       GTK_STOCK_FULLSCREEN },
+#endif
 #ifdef HAVE_GTK_ICON_FACTORY_ADD_ALIAS
     { GAMES_STOCK_REDO_MOVE,        GTK_STOCK_REDO },
     { GAMES_STOCK_UNDO_MOVE,        GTK_STOCK_UNDO },
@@ -337,14 +339,14 @@ games_stock_init (void)
     { GAMES_STOCK_END_GAME,         N_("_End Game"),          0, 0, NULL },
 #endif
 
-    /* Work around maemo brokenness wrt. stock item translations */
-    /* FIXMEchpe: this only applies to maemo3; should be fixed in maemo4 */
-#ifdef HAVE_HILDON
+#ifdef HAVE_MAEMO_3
+    /* Work around maemo brokenness wrt. stock item translations.
+     * See https://bugs.maemo.org/show_bug.cgi?id=1449 . */
     { GTK_STOCK_ABOUT,              N_("_About"),             0, 0, NULL },
     { GTK_STOCK_CANCEL,             N_("_Cancel"),            0, 0, NULL },
     { GTK_STOCK_CLOSE,              N_("_Close"),             0, 0, NULL },
     { GTK_STOCK_OK,                 N_("_OK"),                0, 0, NULL },
-#endif /* HAVE_HILDON */
+#endif /* HAVE_MAEMO_3 */
   };
 
 #undef STOCK_ACCEL
@@ -417,9 +419,14 @@ games_get_license_version (const gchar * game_name,
     N_("You should have received a copy of the GNU General Public License "
        "along with %s; if not, write to the Free Software Foundation, Inc., "
        "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA");
+  static const char license3[] =
+    N_("You should have received a copy of the GNU General Public License "
+       "along with this program.  If not, see <http://www.gnu.org/licenses/>.");
 
-  license_trans = g_strjoin ("\n\n", _(license0), _(license1),
-                             _(license2), NULL);
+  if (version >= 3)
+    license_trans = g_strjoin ("\n\n", _(license0), _(license1), _(license3), NULL);
+  else
+    license_trans = g_strjoin ("\n\n", _(license0), _(license1), _(license2), NULL);
 
 #if !GTK_CHECK_VERSION (2, 8, 0)
   /* We have to manually wrap the text, since the about dialogue cannot
